@@ -46,7 +46,7 @@ class CfnScalingPlan(
         id: builtins.str,
         *,
         application_source: typing.Union["CfnScalingPlan.ApplicationSourceProperty", aws_cdk.core.IResolvable],
-        scaling_instructions: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.ScalingInstructionProperty"]]],
+        scaling_instructions: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.ScalingInstructionProperty"]]],
     ) -> None:
         '''Create a new ``AWS::AutoScalingPlans::ScalingPlan``.
 
@@ -64,11 +64,9 @@ class CfnScalingPlan(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -158,7 +156,7 @@ class CfnScalingPlan(
             self,
             *,
             cloud_formation_stack_arn: typing.Optional[builtins.str] = None,
-            tag_filters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.TagFilterProperty"]]]] = None,
+            tag_filters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.TagFilterProperty"]]]] = None,
         ) -> None:
             '''
             :param cloud_formation_stack_arn: ``CfnScalingPlan.ApplicationSourceProperty.CloudFormationStackARN``.
@@ -221,7 +219,7 @@ class CfnScalingPlan(
             metric_name: builtins.str,
             namespace: builtins.str,
             statistic: builtins.str,
-            dimensions: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.MetricDimensionProperty"]]]] = None,
+            dimensions: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.MetricDimensionProperty"]]]] = None,
             unit: typing.Optional[builtins.str] = None,
         ) -> None:
             '''
@@ -322,7 +320,7 @@ class CfnScalingPlan(
             metric_name: builtins.str,
             namespace: builtins.str,
             statistic: builtins.str,
-            dimensions: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.MetricDimensionProperty"]]]] = None,
+            dimensions: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.MetricDimensionProperty"]]]] = None,
             unit: typing.Optional[builtins.str] = None,
         ) -> None:
             '''
@@ -597,7 +595,7 @@ class CfnScalingPlan(
             resource_id: builtins.str,
             scalable_dimension: builtins.str,
             service_namespace: builtins.str,
-            target_tracking_configurations: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.TargetTrackingConfigurationProperty"]]],
+            target_tracking_configurations: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.TargetTrackingConfigurationProperty"]]],
             customized_load_metric_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.CustomizedLoadMetricSpecificationProperty"]] = None,
             disable_dynamic_scaling: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
             predefined_load_metric_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.PredefinedLoadMetricSpecificationProperty"]] = None,
@@ -815,7 +813,7 @@ class CfnScalingPlan(
             self,
             *,
             key: builtins.str,
-            values: typing.Optional[typing.List[builtins.str]] = None,
+            values: typing.Optional[typing.Sequence[builtins.str]] = None,
         ) -> None:
             '''
             :param key: ``CfnScalingPlan.TagFilterProperty.Key``.
@@ -1006,7 +1004,7 @@ class CfnScalingPlanProps:
         self,
         *,
         application_source: typing.Union[CfnScalingPlan.ApplicationSourceProperty, aws_cdk.core.IResolvable],
-        scaling_instructions: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnScalingPlan.ScalingInstructionProperty]]],
+        scaling_instructions: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnScalingPlan.ScalingInstructionProperty]]],
     ) -> None:
         '''Properties for defining a ``AWS::AutoScalingPlans::ScalingPlan``.
 
